@@ -31,7 +31,6 @@ import time
 import os
 import shutil
 import tempfile
-import cPickle as pickle
 
 import supybot.conf as conf
 import supybot.utils as utils
@@ -42,6 +41,9 @@ from supybot.i18n import PluginInternationalization, internationalizeDocstring
 _ = PluginInternationalization('Scheduler')
 import supybot.world as world
 
+import supybot.utils.minisix as minisix
+pickle = minisix.pickle
+
 datadir = conf.supybot.directories.data()
 filename = conf.supybot.directories.data.dirize('Scheduler.pickle')
 
@@ -67,7 +69,7 @@ class Scheduler(callbacks.Plugin):
         except IOError as e:
             self.log.debug('Unable to open pickle file: %s', e)
             return
-        for name, event in eventdict.iteritems():
+        for name, event in eventdict.items():
             ircobj = callbacks.ReplyIrcProxy(irc, event['msg'])
             try:
                 if event['type'] == 'single': # non-repeating event
@@ -85,7 +87,7 @@ class Scheduler(callbacks.Plugin):
             except AssertionError as e:
                 if str(e) == 'An event with the same name has already been scheduled.':
                     # we must be reloading the plugin, event is still scheduled
-                    self.log.info('Event %s already exists, adding to dict.' % (name,))
+                    self.log.info('Event %s already exists, adding to dict.', name)
                     self.events[name] = event
                 else:
                     raise
@@ -197,7 +199,7 @@ class Scheduler(callbacks.Plugin):
 
         Lists the currently scheduled events.
         """
-        L = self.events.items()
+        L = list(self.events.items())
         if L:
             L.sort()
             for (i, (name, command)) in enumerate(L):
